Skip to contents

get.SCOPE.outputs get the outputs from SCOPE model

Usage

get.SCOPE.outputs(
  data.sim,
  N.sims,
  LUT,
  path.out,
  get.plots,
  get.outputs = NULL,
  get.more.inputs
)

Arguments

data.sim

a list elements generated by the SCOPE model

N.sims

a vector with number of simulations generated by the SCOPE model

LUT

a LUT with the inputs used in the SCOPE model

path.out

path for saving the main files

get.plots

is true, intermediate plots will be generated in Plot folder

get.outputs

If get.outputs = 'ALL', all variables will be retrieved; if get.outputs = 'Main', only the main variables will be retrieved.

get.more.inputs

is true, intermediate plots will be generated in Additional.inputs folder

Author

Carlos Camino (Ported version into R)

Examples

if (FALSE) { # \dontrun{
out <- get.SCOPE.outputs(data.sim, N.sims, LUT, path.out, get.plots = FALSE,
                          get.outputs = "Main", get.more.inputs = FALSE)
} # }