Skip to contents

get.outs.in get the outputs from the SCOPE model. This code is for single simulations

Usage

get.outs.in(data.sim, LUT, path.out, get.plots, get.more.inputs)

Arguments

data.sim

a list elements generated by the SCOPE model

LUT

a list of inputs used by the SCOPE model

path.out

path for saving the main files

get.plots

is true, intermediate plots will be generated in Plot folder

get.more.inputs

is true, intermediate plots will be generated in Additional.inputs folder

Author

Carlos Camino (Ported version into R)

Examples

if (FALSE) { # \dontrun{
get.outs.in(data.sim, LUT, path.out, get.plots = TRUE, get.more.inputs = FALSE)
} # }