Skip to contents

get.spectra.SCOPE get.spectra.SCOPE Calculates the spectra of hemisperical and directional observed #' a function to get the spectral characteristics for SCOPE model

Usage

get.spectra.SCOPE(getSpectral = T)

Arguments

getSpectral

is T get the spectral object needed for SCOPE

Value

a list with al spectral ranges and Intervals

Examples

spectral <- get.spectra.SCOPE(getSpectral = TRUE)