Skip to contents

This function generates samples of a Look-Up Table (LUT) to analyze variations in plant traits required for a specific scope.

Usage

getLUT.SCOPE(inputLUT, nLUT = 100, setseed = 123)

Arguments

inputLUT

A table (LUT) containing data.

nLUT

Number of samples to generate from the input LUT. Defaults to 100.

setseed

Seed value to ensure reproducibility of results. Defaults to 123.

Value

Returns a data frame containing the generated LUT samples.

Examples

if (FALSE) { # \dontrun{
inputLUT <- read.table(system.file("input", "inputs_SCOPE.csv", package = "SCOPEinR"),
                       header = TRUE, sep = ",")
getLUT.SCOPE(inputLUT = inputLUT, nLUT = 100, setseed = 123)
} # }