Skip to contents

An example leaf optical spectrum (reflectance and/or transmittance vs. wavelength) used for testing and illustrating the leaf optical models.

Usage

leaf_spectrum

Format

A data frame with a wavelength column and one or more reflectance/transmittance columns.