Calculates pi/2-the angle of the sun with the slope of the surface.
calczenithangle.RdCalculates pi/2-the angle of the sun with the slope of the surface.
Value
A list zenith.angles intended to contain:
- Omega_s
Hour angle of the sun (rad).
- Fi_s
"Classic" solar zenith angle, perpendicular to the horizontal plane (rad).
- Fi_g
Projected slope of the surface, in the plane through the solar beam and the vertical (rad).
- Fi_gs
Angle of the sun with the vector perpendicular to the (possibly sloped) surface, i.e.
pi/2minus the surface solar elevation angle (rad).