get.SCOPE get simulations based on SCOPE model
get.SCOPE.RdMain module for calling the SCOPE model
Usage
get.SCOPE(
LUT,
n.LUT = 10,
options.SCOPE,
optipar,
path.out,
leaf.model = "fluspect-CX",
canopy.model = "fourSAIL",
get.outputs,
get.plots = T
)Arguments
- LUT
leaf, biochemistry, viewing angles,meteo, and canopy properties needed for running SCOPE model.
- n.LUT
number of input used for simulating with SCOPE model
- options.SCOPE
simulation options controlling the SCOPE run, such as the atmospheric correction and whether to correct the total irradiance if a specific value is provided instead of the usual Modtran output.
- optipar
leaf optical parameters used by the selected leaf model (e.g. Fluspect refractive index and specific absorption coefficients).
- path.out
folder for saving the SCOPE outputs.
- leaf.model
Not currently functional – SCOPE always uses its own multi-layer Fluspect-Cx leaf optics (
get.fluspect_mSCOPE), required by the fluorescence pipeline (RTMf). Passing anything other than'fluspect-CX'triggers a warning. Kept as an argument for forward compatibility.- canopy.model
Not currently functional – SCOPE always uses its own multi-layer canopy engine (
getRTMo), which is not the same code asToolsRTM::foursail()/foursail2()/inform()and isn't swappable without reimplementing those inside SCOPE's multi-layer/gap-probability framework. Passing anything other than'fourSAIL'triggers a warning. Kept as an argument for forward compatibility.- get.outputs
if get.outputs = 'ALL' all variables were retrieved; if get.outputs = 'Main' the main variables were retrieved. By default SCOPE uses get.outputs = 'ALL', for processiong huge LUT is recommended get.outputs = 'Main'.
- get.plots
is true plot the intermediate plots
References
Yang, P., E. Prikaziuk, W. Verhoef, and C. van der Tol. 2020. “SCOPE 2.0: A Model to Simulate Vegetated Land Surface Fluxes and Satellite Signals.” Geoscientific Model Development Discussions 2020: 1–26. https://doi.org/10.5194/gmd-2020-251.
Van der Tol, C., W. Verhoef, J Timmermans, A Verhoef, and Z Su. 2009. “An Integrated Model of Soil-Canopy Spectral Radiances, Photosynthesis, Fluorescence, Temperature and Energy Balance.” Biogeosciences 6 (12): 3109–29. https://doi.org/10.5194/bg-6-3109-2009.