get.outs.lut get the outputs from SCOPE model. This code is for a LUT of simulations
get.outs.lut.v2.Rdget.outs.lut get the outputs from SCOPE model. This code is for a LUT of simulations
Arguments
- data.sim
list elements generated by the SCOPE model
- LUT
a list of inputs used in the SCOPE model
- path.out
path for saving the main files
- get.plots
is true, intermediate plots will be generated in Plot folder
- get.outputs
If get.outputs = 'ALL', all variables will be retrieved; if get.outputs = 'Main', only the main variables will be retrieved. By default, SCOPE uses get.outputs = 'ALL', for processing a huge LUT, it is recommended to use get.outputs = 'Main'.
- nSamples
number of LUT samples to process; used to size progress reporting for the extraction loop.