subfunction pm for stability correction (eg. Paulson, 1970)
get.psim.Rdget.psim computes the stability correction function for momentum
transfer, used to correct the logarithmic wind profile for non-neutral
atmospheric conditions.
Arguments
- z
numeric. Height above the zero-plane displacement height, in meters.
- L
numeric. Monin-Obukhov length, in meters (atmospheric stability scale).
- unstable
logical. TRUE if the atmosphere is in an unstable stratification regime.
- stable
logical. TRUE if the atmosphere is in a stable stratification regime.
- x
numeric. Stability correction intermediate variable, typically
(1 - 16*z/L)^0.25.