get.spectra.SCOPE get.spectra.SCOPE Calculates the spectra of hemisperical and directional observed #' a function to get the spectral characteristics for SCOPE model
get.spectra.SCOPE.Rdget.spectra.SCOPE
get.spectra.SCOPE Calculates the spectra of hemisperical and directional observed #' a function to get the spectral characteristics for SCOPE model