Example leaf reflectance/transmittance spectrum
leaf_spectrum.RdAn example leaf optical spectrum (reflectance and/or transmittance vs. wavelength) used for testing and illustrating the leaf optical models.
leaf_spectrum.RdAn example leaf optical spectrum (reflectance and/or transmittance vs. wavelength) used for testing and illustrating the leaf optical models.